---
layout: default
title: Index
---
<div class="left-area">
    {% for post in posts | batch(5) | first%}
    <article class="post type-post status-publish hentry category-people entry clearfix">
        <p class="meta-info">Posted  by {{ post.author }} on <a href="{{ post.url }}">{{ post.pub_time.strftime('%b %d,%Y') }}</p>

            <div class="post_content clearfix">
                <h1 class="title"><a href="{{ post.url }}">{{ post.title }}</a></h1>
                <hr/>
                {{ post.front_html | safe }}
                <a href="{{ post.url }}" class="more">{{ site.excerpt_link }}</a>
            </div>
        </article>
    {% endfor %}
    {% include '_includes/paginate.html' %}
</div>
{% include "_includes/sidebar.html" %}

<script type="text/javascript">
/* * * CONFIGURATION VARIABLES: EDIT BEFORE PASTING INTO YOUR WEBPAGE * * */
var disqus_shortname = '{{ site.disqus_short_name }}'; // required: replace example with your forum shortname

/* * * DON'T EDIT BELOW THIS LINE * * */
(function () {
 var s = document.createElement('script'); s.async = true;
 s.type = 'text/javascript';
 s.src = '//' + disqus_shortname + '.disqus.com/count.js';
 (document.getElementsByTagName('HEAD')[0] || document.getElementsByTagName('BODY')[0]).appendChild(s);
 }());
</script>
