---
layout: default
title: Blog Categories
---
<div class="left-area">
{% for category in categories recursive %}
<h3 id="{{ category }}" class="main-title">{{ category }}</h3>
{% for post in categories[category].posts %}
<div class="archives">
<div class="archives-content">
    <p class="meta-info">{{ post.pub_time.strftime('%b %d, %Y') }} , {% for category in post.categories %}{{ category }} {% endfor %}</p>
    <h4><a href="{{ post.url }}">{{ post.title }}</a></h4>
</div>

</div>
{% endfor %}
{% endfor %}
</div>
{% include "_includes/sidebar.html" %}
