---
layout: default
---
<div class="left-area">
    <article class="post entry clearfix">
    <div class="post_content clearfix">
    <h1 class="title">{{ page.title }}</h1>
    <hr/>
    {{ page.html | safe }}
    </div>
    </article>
</div>

{% if page.comment == True%}
    {% include "_includes/comments.html" %}
{% endif %}

{% include "_includes/sidebar.html" %}
