{% include "_includes/head.html" %}
<body>
<div id="header" class="container">{% include "_includes/header.html" %}</div>
<div id="menu">
    <div class="container">{% include "_includes/navbar.html" %}</div>
</div>
<div class="main-area">
    <div class="container">
        <div id="content-area" class="clearfix">
            {{ content }}
        </div>
    </div>
</div>
{% include "_includes/footer.html" %}
</body>
</html>
