{% for link in site.navbar %}
{% for item in link %}
<a href="{{ link[item] }}" class="mobile_nav closed">{{ item }}</a>
{% endfor %}
{% endfor %}

<nav id="second-menu" class="clearfix">
    <ul id="menu-categories" class="nav">
        {% for link in site.navbar %}
        {% for item in link %}
        <li id="" class="menu-item"><a href="{{ link[item] }}" class="mobile_nav closed">{{ item }}</a></li>
        {% endfor %}
        {% endfor %}
    </ul>
{% if site.simple_search %}
<form action="{{ site.simple_search }}" class="search-form" method="get">
  <fieldset role="search">
    <input type="hidden" name="q" value="site:{{ site.url }}" />
    <input class="searchinput" type="text" name="q" results="0" placeholder="Search"/>
  </fieldset>
</form>
{% endif %}
</nav>
