<link href='http://fonts.googleapis.com/css?family=Hammersmith+One' rel='stylesheet' type='text/css'>
<!DOCTYPE html>
<html lang="en-US">
<head>
<meta charset="UTF-8" /><title>{% if post %}{{ post.title }}{% elif page %}{{ page.title }}{% elif title %}{{ title }}{% else %}{{ site.title }}{% endif %} | {{ site.title }}</title>
<meta name="author" content="{{ site.author }}">
<meta name="description" content="{% if post %}{% if post.description %}{{ post.description }}{% else %}{{ post.html | striptags | truncate(length=255 ,killwords=False)}}{% endif %}{% elif page %}{% if page.description %}{{ page.description }}{% else %}{{ page.html | striptags | truncate(length=255 ,killwords=False)}}{% endif %}{% else %}{{ site.description }}{% endif %}">
<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=no">
<meta property="og:site_name" content=""/>

<link rel="stylesheet" href="/css/style.css" type="text/css" />
<link rel="stylesheet" href="/css/pygments.css" type="text/css" />
<!--[if lt IE 9]><script src="http://html5shiv.googlecode.com/svn/trunk/html5.js"></script><![endif]-->
{% if site.comment_system == "disqus" %}
<script async="" type="text/javascript" src="//{{ site.disqus_short_name }}.disqus.com/count.js"></script>
{% endif %}

<style>
#featured .flex-direction-nav a:hover, #video-slider-section .flex-direction-nav a:hover { background-color: #ffb600; }
#featured_section .active-slide .post-meta, #featured_section .switcher_hover .post-meta, .et_tab_link_hover .post-meta { background: #0099FF; }
h3.main-title { background-color: #0099FF; -moz-box-shadow: inset 0 0 10px #0099FF; -webkit-box-shadow: inset 0 0 10px #0099FF; box-shadow: inset 0 0 10px #0099FF; border: 1px solid #0099FF; }
a { color: #0099FF; }
.et_video_play { background-color: #0099FF; }
#second-menu > ul > li > a:hover { background-color: #0099FF; }
#second-menu ul ul li a:hover { background-color: #ffb122; }
#second-menu ul.nav li ul { background: #0099FF; }
#second-menu ul ul li a { border-top: 1px solid #0099FF; }
</style>

</head>
