<div class="widget">
<h4 class="widgettitle">Contacts</h4>
<ul>
<li><a class="social weibo" href='http://weibo.com/{{ site.weibo_uid }}' target="_blank">Weibo</a></li>
<li><a class="social google" href='mailto:gmail@gmail.com' target="_blank">Gmail</a></li>
<li><a class="social facebook" href='http://facebook.com/' target="_blank">Facebook</a></li>
<li><a class="social twitter" href='http://twitter.com/' target="_blank" >Twitter</a></li>
<li><a class="social github" href='http://github.com/' target="_blank"      >Github</a></li>
<li><a class="social instagram" href='http://instagram.com/' target="_blank"   >Instagram</a></li>
<li><a class="social soundcloud" href='http://soundcloud.com/' target="_blank"  >Soundcloud</a></li>
</ul>
</div>
