.codehilite .hll { background-color: #f8f8f8; border: 1px solid #ccc; padding: 6px 10px; border-radius: 3px; }
.codehilite .c { color: #999988; font-style: italic; }
.codehilite .err { color: #a61717; background-color: #e3d2d2; }
.codehilite .k { font-weight: bold; }
.codehilite .o { font-weight: bold; }
.codehilite .cm { color: #999988; font-style: italic; }
.codehilite .cp { color: #999999; font-weight: bold; }
.codehilite .c1 { color: #999988; font-style: italic; }
.codehilite .cs { color: #999999; font-weight: bold; font-style: italic; }
.codehilite .gd { color: #000000; background-color: #ffdddd; }
.codehilite .gd .x { color: #000000; background-color: #ffaaaa; }
.codehilite .ge { font-style: italic; }
.codehilite .gr { color: #aa0000; }
.codehilite .gh { color: #999999; }
.codehilite .gi { color: #000000; background-color: #ddffdd; }
.codehilite .gi .x { color: #000000; background-color: #aaffaa; }
.codehilite .go { color: #888888; }
.codehilite .gp { color: #555555; }
.codehilite .gs { font-weight: bold; }
.codehilite .gu { color: #800080; font-weight: bold; }
.codehilite .gt { color: #aa0000; }
.codehilite .kc { font-weight: bold; }
.codehilite .kd { font-weight: bold; }
.codehilite .kn { font-weight: bold; }
.codehilite .kp { font-weight: bold; }
.codehilite .kr { font-weight: bold; }
.codehilite .kt { color: #445588; font-weight: bold; }
.codehilite .m { color: #009999; }
.codehilite .s { color: #dd1144; }
.codehilite .n { color: #333333; }
.codehilite .na { color: teal; }
.codehilite .nb { color: #0086b3; }
.codehilite .nc { color: #445588; font-weight: bold; }
.codehilite .no { color: teal; }
.codehilite .ni { color: purple; }
.codehilite .ne { color: #990000; font-weight: bold; }
.codehilite .nf { color: #990000; font-weight: bold; }
.codehilite .nn { color: #555555; }
.codehilite .nt { color: navy; }
.codehilite .nv { color: teal; }
.codehilite .ow { font-weight: bold; }
.codehilite .w { color: #bbbbbb; }
.codehilite .mf { color: #009999; }
.codehilite .mh { color: #009999; }
.codehilite .mi { color: #009999; }
.codehilite .mo { color: #009999; }
.codehilite .sb { color: #dd1144; }
.codehilite .sc { color: #dd1144; }
.codehilite .sd { color: #dd1144; }
.codehilite .s2 { color: #dd1144; }
.codehilite .se { color: #dd1144; }
.codehilite .sh { color: #dd1144; }
.codehilite .si { color: #dd1144; }
.codehilite .sx { color: #dd1144; }
.codehilite .sr { color: #009926; }
.codehilite .s1 { color: #dd1144; }
.codehilite .ss { color: #990073; }
.codehilite .bp { color: #999999; }
.codehilite .vc { color: teal; }
.codehilite .vg { color: teal; }
.codehilite .vi { color: teal; }
.codehilite .il { color: #009999; }
.codehilite .gc { color: #999; background-color: #EAF2F5; }
