<div id="footer">
    <div class="container clearfix">
        <p id="copyright">&copy; 2013 <a href="/" title="">{{ site.author }}</a> | Powered by <a href="http://crotal.org" target="_blank">Crotal</a></p>
    </div>
</div>
{% include "_includes/after_footer.html" %}
